@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     03/12/2006
-## RCS-ID:      $Id: Utility.pm 2189 2007-08-21 18:15:31Z mbarbon $
+## RCS-ID:      $Id: Utility.pm 2772 2010-02-01 14:23:16Z mdootson $
 ## Copyright:   (c) 2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -19,7 +19,8 @@ our @EXPORT = qw(resize_to);
 
 sub resize_to {
     my( $image, $size ) = @_;
-
+    # seems not to work on Mac
+    return $image if Wx::wxMAC();
     if( $image->GetWidth != $size || $image->GetHeight != $size ) {
         return Wx::Bitmap->new
           ( Wx::Image->new( $image )->Rescale( $size, $size ) );
