@@ -4,7 +4,7 @@
 ## Author:      Mark Dootson
 ## Modified by:
 ## Created:     06 Feb 2010
-## RCS-ID:      $Id: wxOverlay.pm 3120 2011-11-18 18:50:54Z mdootson $
+## RCS-ID:      $Id: wxOverlay.pm 3450 2013-03-30 04:03:16Z mdootson $
 ## Copyright:   (c) 2010 Mark Dootson
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -16,7 +16,7 @@ use Wx 0.97;
 use Wx qw( :misc :window :panel :sizer);
 use base qw( Wx::Panel );
 
-sub add_to_tags { qw(new misc) }
+sub add_to_tags { qw( misc ) }
 sub title { 'wxOverlay' }
 
 sub new {
